#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2020/1/2
# @time: 15:03
# @doc:
# Copyright © 2020 natloc_developer. All rights reserved.
#

import sys
import os

sys.path.insert(0, os.path.dirname(sys.path[0]))
print(sys.path[0])

import nat.datetime
from thd.calendar.ics import ICS_XiaoBangGuiHua

print(ICS_XiaoBangGuiHua().reqIcal().isEventDay())



#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/12
# @time: 18:16
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#

from nat_lib.var_type import nat_string
from nat_lib.archive import nat_path
from nat_lib.archive import nat_plist
from nat_lib.archive import nat_file
from nat_lib.log import nat_console
from nat_lib.system import nat_cmd


# 基础打包类：支持 打包 + 导出
class _Archive(object):

    __XC_PROJECT_SUFFIX = "xcodeproj"
    __XC_WORKSPACE_SUFFIX = "xcworkspace"

    __ARCHIVE_SUFFIX = "xcarchive"
    __MANIFEST_PLIST_FILENAME = "manifest.plist"
    __EXPORT_OPTIONS_PLIST_FILENAME = "ExportOptions.plist"

    __DEFAULT_EXPORTED_ARCHIVE_DIR_BASENAME = "exportedArchive"
    __DEFAULT_EXPORTED_IPA_DIR_BASENAME = "ipa"

    __DEFAULT_UPDATE_MD_BASENAME = "update"

    _ARCHIVE_ERR_PRIFIX = u"iOS 打包 * "



    # 项目路径
    __projectDirPath = ""
    # 项目名
    _projectName = ""

    # xccodeproj 目录
    __xcCodeProjDirPath = ""
    # xcworkspace 目录
    __xcWorkSpaceDirPath = ""



    def __init__(self, projectDirPath):
        # 项目路径、项目名
        projectPath = nat_path.getAbsPath(nat_string.trim(projectDirPath))
        if not nat_path.isDir(projectPath):
            self._exitLog(u"%s初始化失败：项目目录不存在，%s" %(projectPath))

        projectName = nat_path.getBasename(projectDirPath)
        if "" == projectName:
            self._exitLog(u"初始化失败：项目目录名为空，%s" %(projectName))

        self.__projectDirPath = projectPath
        self._projectName = projectName


        # 项目配置
        xcProjDirPath = nat_path.join(self.__projectDirPath, "%s.%s" %(self._projectName, self.__XC_PROJECT_SUFFIX))
        if not nat_path.isDir(xcProjDirPath):
            self._exitLog(u"初始化失败：.xccodeproj 不存在：%s" %(projectDirPath))

        self.__xcCodeProjDirPath = xcProjDirPath

        xcWorkspaceDirPath = nat_path.join(self.__projectDirPath, "%s.%s" %(self._projectName, self.__XC_WORKSPACE_SUFFIX))
        if nat_path.isDir(xcWorkspaceDirPath):
            self.__xcWorkSpaceDirPath = xcWorkspaceDirPath

        if "" == self.__getAvailTeamID():
            self._exitLog(u"初始化失败：必须设置 teamID")


        # update.md
        if self._isForceEnableUpdateMd():
            updateMdPath = self._getAvailUpdateMdPath()
            if not nat_path.isFile(updateMdPath):
                nat_file.createEmptyFile(updateMdPath)

            content = nat_string.trim(self._getUpdateContent())
            if "" == content:
                self._onErrorUpdateMdEmpty()
                self._exitLog(u"初始化失败：必须填写更新内容到 %s" %(nat_path.getFilename(updateMdPath)))

            if not self._isUpdateMdContentValid():
                self._exitLog(u"初始化失败：%s 的内容格式不正确" %(nat_path.getFilename(updateMdPath)))


        # provisioning profile
        if [] == self.__getAvailProvisioningProfiles():
            self._exitLog(u"初始化失败：必须设置 bundleID 和 provisioningProfile")



    # --- 功能函数

    # 执行项目清理工作
    # return: bool
    def doClean(self):
        exportedArchiveDirPath = self._getAvailExportedArchiveDirPath()
        nat_path.rmDirRecursive(exportedArchiveDirPath)

        exportedIpaDirPath = self._getAvailExportedIpaDirPath()
        nat_path.rmDirRecursive(exportedIpaDirPath)

        (typeStr, dirPath) = self.__getXc()
        cmdStr = "xcodebuild clean -%s %s -scheme %s -configuration %s" %(typeStr, dirPath, self.__getAvailScheme(), self._getIsReleaseModeStr())

        return nat_cmd.cmd(cmdStr)

    # 编译 IPA 并生成 *.xcarchive 文件
    # return: bool
    def doGenArchive(self):
        (typeStr, dirPath) = self.__getXc()

        exportedArchivePath = self.__getAvailExportedArchivePath()
        cmdStr = "xcodebuild archive -%s %s -scheme %s -configuration %s -archivePath %s" %(typeStr, dirPath, self.__getAvailScheme(), self._getIsReleaseModeStr(), exportedArchivePath)

        return nat_cmd.cmd(cmdStr)

    # 由 archive 导出 AdHoc 类型的 IPA
    # return: bool
    def doExportIpaForAdHoc(self):
        return self.__doExportIPA(True)

    # 由 archive 导出 AppStore 类型的 IPA
    # return: bool
    def doExportIpaForAppStore(self):
        return self.__doExportIPA(False)

    # 由 archive 导出 IPA
    # param: isAdHoc :: bool   # true-AdHoc；false-AppStore
    # return: bool
    def __doExportIPA(self, isAdHoc):
        exportedArchivePath = self.__getAvailExportedArchivePath()
        if not nat_path.isDir(exportedArchivePath):
            self._exitLog(u"导出 IPA 失败：archive 不存在：%s" %(exportedArchivePath))

        # 创建配置选项文件
        exportedIpaDirPath = self._getAvailExportedIpaDirPath()
        exportOptsPlistPath = nat_path.join(self._getAvailExportedArchiveDirPath(), self.__EXPORT_OPTIONS_PLIST_FILENAME)
        if isAdHoc:
            self.__createExportOptsPlistFileForAdHoc(exportOptsPlistPath)
        else:
            self.__createExportOptsPlistFileForAppStore(exportOptsPlistPath)

        autoSigningAndGenProfileStr = ""
        if self._isEnableAutoSigningAndGenProfile():
            autoSigningAndGenProfileStr = "-allowProvisioningUpdates"

        cmdStr = "xcodebuild -exportArchive %s -archivePath %s -exportPath %s -exportOptionsPlist %s" %(autoSigningAndGenProfileStr, exportedArchivePath, exportedIpaDirPath, exportOptsPlistPath)

        return nat_cmd.cmd(cmdStr)

    # 上传 IPA 到 AppStore
    # return: bool
    def doUploadToAppStore(self):
        cmd = "xcrun"
        if not nat_cmd.hasCmd(cmd):
            self._exitLog(u"xcrun 命令未安装")

        ipaFile = self.__getAvailExportedIpaPath()
        if not nat_path.isFile(ipaFile):
            self._exitLog(u"ipa 文件不存在")

        p8Path = self.__getAvailUploadAppstoreApiP8Path()
        if not nat_path.isFile(p8Path):
            self._exitLog(u"p8 文件不存在")

        apiKey = nat_string.trim(self._getUploadAppstoreApiKey())
        apiIssuer = nat_string.trim(self._getUploadAppstoreApiIssuer())
        if "" == apiIssuer:
            self._exitLog(u"api issuer 不能为空")


        cmdStr = "xcrun altool --%s-app -t ios -f %s --apiKey %s --apiIssuer %s"

        # 验证
        cmdValidateStr = cmdStr %("validate", ipaFile, apiKey, apiIssuer)
        if not nat_cmd.cmd(cmdValidateStr):
            self._exitLog(u"验证上传失败")

        # 上传
        cmdValidateStr = cmdStr %("upload", ipaFile, apiKey, apiIssuer)
        if not nat_cmd.cmd(cmdValidateStr):
            self._exitLog(u"上传到 appstore 失败")

        return True


    # 获取可用的 export 导出目录
    # return: string
    def _getAvailExportedDirPath(self):
        dirPath = nat_path.getAbsPath( nat_string.trim(self._getExportedArchiveDirPath()) )
        if not nat_path.isDir(dirPath) and "" != dirPath:
            nat_path.mkDirRecursive(dirPath)

        # 创建后再次检查
        if not nat_path.isDir(dirPath):
            dirPath = self.__projectDirPath

        return dirPath



    # 获取有效的打包后生成的 *.xcarchive 的目录
    # return: string
    def _getAvailExportedArchiveDirPath(self):
        dirPath = self._getAvailExportedDirPath()

        dirBasename = nat_string.trim(self._getExportedArchiveDirBasename())
        if "" == dirBasename:
            dirBasename = self.__DEFAULT_EXPORTED_ARCHIVE_DIR_BASENAME

        # archive 目录
        archiveDirPath = nat_path.join(dirPath, dirBasename)
        if nat_path.mkDirRecursive(archiveDirPath):
            return archiveDirPath
        else:
            self._exitLog(u"创建 *.xcarchive 所在的目录失败：%s" %(archiveDirPath))

    # 获取有效的打包后生成的 *.xcarchive 的路径
    # return: string
    def __getAvailExportedArchivePath(self):
        dirPath = self._getAvailExportedArchiveDirPath()

        basename = nat_string.trim(self._getExportedArchiveBasename())
        if "" == basename:
            basename = self._projectName

        return nat_path.join(dirPath, "%s.%s" %(basename, self.__ARCHIVE_SUFFIX))



    # 获取有效的 *.xcarchive 导出的 ipa 的目录
    # return: string
    def _getAvailExportedIpaDirPath(self):
        dirPath = nat_path.getAbsPath( nat_string.trim(self._getExportedIpaDirPath()) )
        if not nat_path.isDir(dirPath) and "" != dirPath:
            nat_path.mkDirRecursive(dirPath)

        # 创建后再次检查
        if not nat_path.isDir(dirPath):
            dirPath = self._getAvailExportedArchiveDirPath()

        dirBasename = self._getAvailExportedIpaDirBasename()

        # ipa 导出目录
        exportedIpaDirPath = nat_path.join(dirPath, dirBasename)
        if nat_path.mkDir(exportedIpaDirPath):
            return exportedIpaDirPath
        else:
            self._exitLog(u"创建 ipa 的导出目录失败：%s" %(exportedIpaDirPath))

    def _getAvailExportedIpaDirBasename(self):
        dirBasename = nat_string.trim(self._getExportedIpaDirBasename())
        if "" == dirBasename:
            dirBasename = self.__DEFAULT_EXPORTED_IPA_DIR_BASENAME

        return dirBasename

    def __getAvailExportedIpaPath(self):
        ipaDirPath = self._getAvailExportedIpaDirPath()
        return nat_path.join(ipaDirPath, "%s.ipa" %(self._projectName))

    # 获取导出 IPA 目录下的 manifest.plist 文件路径
    # return: string
    def _getAvailExportedIpaManifestPlistPath(self):
        return nat_path.join(self._getAvailExportedIpaDirPath(), self.__MANIFEST_PLIST_FILENAME)



    # 获取 *.p8 文件名
    # return: string
    def __getAvailUploadAppstoreApiP8Filename(self):
        apiKey = nat_string.trim(self._getUploadAppstoreApiKey())
        if "" == apiKey:
            return ""
        else:
            return "AuthKey_%s.p8" %(apiKey)

    # 获取 *.p8 文件路径
    # return: string
    def __getAvailUploadAppstoreApiP8Path(self):
        dir = self._getUploadAppstoreApiP8Dir()
        if not nat_path.isDir(dir):
            dir = nat_path.join( nat_path.getUserHomePath(), ".private_keys" )

        filename = self.__getAvailUploadAppstoreApiP8Filename()
        if "" == filename:
            return ""
        else:
            return nat_path.join(dir, filename)



    # 输出 log 日志并退出
    def _exitLog(self, content):
        nat_console.exit(u"%s%s" %(self._ARCHIVE_ERR_PRIFIX, content))

    # 获取有效的 工程配置目录
    # return: (typeStr, dirPath)
    def __getXc(self):
        if "" != self.__xcWorkSpaceDirPath:
            return ("workspace", self.__xcWorkSpaceDirPath)
        else:
            return ("project", self.__xcCodeProjDirPath)



    # 删除生成的 *.xcarchive 文件
    def removeExportedArchive(self):
        nat_path.rmDirRecursive(self.__getAvailExportedArchivePath())

    # 删除生成的 *.ipa 文件
    def removeExportedIap(self):
        nat_path.rmFile(self.__getAvailExportedIpaPath())



    # 创建导出 IPA 的选项配置文件：AdHoc
    def __createExportOptsPlistFileForAdHoc(self, exportOptsPlistPath):
        if not nat_path.isValidFilePath(exportOptsPlistPath):
            self._exitLog(u"创建 archive 的选项配置文件失败，路径不合法：%s" %(exportOptsPlistPath))

        elif not nat_plist.createEmptyFile(exportOptsPlistPath):
            self._exitLog(u"创建 archive 的选项配置文件失败：%s" %(exportOptsPlistPath))

        else:
            nat_plist.addStr(exportOptsPlistPath, "teamID", self._getTeamID())

            nat_plist.addStr(exportOptsPlistPath, "method", "ad-hoc")
            nat_plist.addStr(exportOptsPlistPath, "thinning", "<none>")
            nat_plist.addBool(exportOptsPlistPath, "stripSwiftSymbols", True)
            nat_plist.addBool(exportOptsPlistPath, "compileBitcode", True)

            self.__manageExportOptsPlistFileSigning(exportOptsPlistPath)

            dictKey = "manifest"
            downloadUrlPrefix = nat_path.join(self.__getDownloadIpaUrlDomainPath(), self._projectName)
            nat_plist.addDict(exportOptsPlistPath, dictKey)
            nat_plist.addStr(exportOptsPlistPath, "appURL", "%s.ipa" %(downloadUrlPrefix), dictKey)
            nat_plist.addStr(exportOptsPlistPath, "displayImageURL", "%s.57.png" %(downloadUrlPrefix), dictKey)
            nat_plist.addStr(exportOptsPlistPath, "fullSizeImageURL", "%s.512.png" %(downloadUrlPrefix), dictKey)


    # 创建导出 IPA 的选项配置文件：AppStore
    def __createExportOptsPlistFileForAppStore(self, exportOptsPlistPath):
        if not nat_path.isValidFilePath(exportOptsPlistPath):
            self._exitLog(u"创建 archive 的选项配置文件失败，路径不合法：%s" %(exportOptsPlistPath))

        elif not nat_plist.createEmptyFile(exportOptsPlistPath):
            self._exitLog(u"创建 archive 的选项配置文件失败：%s" %(exportOptsPlistPath))

        else:
            nat_plist.addStr(exportOptsPlistPath, "teamID", self._getTeamID())
            nat_plist.addStr(exportOptsPlistPath, "method", "app-store")
            nat_plist.addBool(exportOptsPlistPath, "stripSwiftSymbols", True)
            nat_plist.addBool(exportOptsPlistPath, "uploadSymbols", True)
            nat_plist.addBool(exportOptsPlistPath, "uploadBitcode", True)

            self.__manageExportOptsPlistFileSigning(exportOptsPlistPath)

    # 管理配置文件的签名信息
    def __manageExportOptsPlistFileSigning(self, exportOptsPlistPath):
        bundleIdProvisionList = self.__getAvailProvisioningProfiles()
        bundleIdProvisionLen = len(bundleIdProvisionList)

        nat_plist.addStr(exportOptsPlistPath, "destination", "export")

        # 签名方式
        if 0 == bundleIdProvisionLen:
            signingStyle = "automatic"
        else:
            signingStyle = "manual"

        nat_plist.addStr(exportOptsPlistPath, "signingStyle", signingStyle)

        # profile
        if bundleIdProvisionLen > 0:
            dictKey = "provisioningProfiles"
            nat_plist.addDict(exportOptsPlistPath, dictKey)
            for (bundleID, provisioningProfileName) in bundleIdProvisionList:
                nat_plist.addStr(exportOptsPlistPath, bundleID, provisioningProfileName, dictKey)

        # certificate
        certificateName = self.__getAvailCertificateName()
        if "" != certificateName:
            nat_plist.addStr(exportOptsPlistPath, "signingCertificate", certificateName)


    # 获取 ipa 的下载域名前缀地址，不包含 suffix 部分
    def __getDownloadIpaUrlDomainPath(self):
        domain = nat_string.trim(self._getDownloadIpaUrlDomain())
        urlPath = nat_string.trim(self._getDownloadIpaUrlPath())

        if not domain.startswith("https://") and not domain.startswith("http://"):
            self._exitLog(u"ipa 的下载地址必须以 https 或 http 开头：%s" %(domain))

        if domain.endswith("/"):
            domain = domain[:-1]

        if "" != urlPath and "/" != urlPath[0]:
            urlPath = u"/%s" %(urlPath)

        return domain + urlPath

    # return: string
    def __getAvailTeamID(self):
        return nat_string.trim( self._getTeamID() )

    # return: string
    def __getAvailScheme(self):
        scheme = nat_string.trim( self._getScheme() )
        if "" == scheme:
            return self._projectName
        else:
            return scheme

    # return: string
    def _getIsReleaseModeStr(self):
        if self._getIsReleaseMode():
            return "Release"
        else:
            return "Debug"

    # 获取 update.md 文件的路径
    # return: string
    def _getAvailUpdateMdPath(self):
        basename = nat_string.trim(self._getUpdateMdBasename())
        if "" == basename:
            basename = self.__DEFAULT_UPDATE_MD_BASENAME

        return nat_path.join(self.__projectDirPath, "%s.md" %(basename))

    # 获取更新的内容
    # return: string
    def _getUpdateContent(self):
        return ""

    # 可选：需子类实现
    # 设置指定的 profile；为空则使用
    # return: [(BundleID: string, ProfileBaseName: string), ...]   #
    def __getAvailProvisioningProfiles(self):
        availList = []
        for (bundleId, provisioningName) in self._getProvisioningProfiles():
            bundleId = nat_string.trim(bundleId)
            provisioningName = nat_string.trim(provisioningName)

            if "" != bundleId and "" != provisioningName:
                availList.append((bundleId, provisioningName))

        return availList


    # 获取有效的 证书 名
    # return: string
    def __getAvailCertificateName(self):
        return nat_string.trim(self._getSigningCertificate())



    # --- 必选：需子类实现


    # 必选：需子类实现
    # 获取下载 ipa 的域名，必须以 https:// 或 http:// 开头
    # return: string
    def _getDownloadIpaUrlDomain(self):
        return ""

    # 必选：需子类实现
    # 获取下载 ipa 的路径，以 / 开头
    # return: string
    def _getDownloadIpaUrlPath(self):
        return ""

    # 必选：需子类实现
    # 开发者 teamID，用于导出 IPA
    # return: string
    def _getTeamID(self):
        return ""



    # --- 可选：需子类实现

    # 可选：需子类实现
    # 获取打包后生成的 *.xcarchive 的目录；如果为空则默认使用 项目的根目录
    # 完整目录由：DirPath/ DirBasename/ 组成
    # return: stringå
    def _getExportedArchiveDirPath(self):
        return ""

    # 可选：需子类实现
    # 获取打包后生成的 *.xcarchive 的目录名；如果为空则默认使用 exportedArchive
    # 完整目录由：DirPath/ DirBasename/ 组成
    # return: string
    def _getExportedArchiveDirBasename(self):
        return ""

    # 可选：需子类实现
    # 获取打包后生成的 *.xcarchive 的 basename；如果为空则默认使用项目名
    # return: string
    def _getExportedArchiveBasename(self):
        return ""


    # 可选：需子类实现
    # 获取由 *.xcarchive 导出的 ipa 的目录；如果为空则默认使用 self._getAvailExportedArchiveDirPath()
    # 完整目录由：DirPath/ DirBasename/ 组成
    # return: string
    def _getExportedIpaDirPath(self):
        return ""

    # 可选：需子类实现
    # 获取由 *.xcarchive 导出的 ipa 的目录名；如果为空则默认使用 ipa
    # 完整目录由：DirPath/ DirBasename/ 组成
    # return: string
    def _getExportedIpaDirBasename(self):
        return ""


    # 可选：需子类实现
    # TARGET 的 scheme；如果为空则默认使用项目名
    # return: string
    def _getScheme(self):
        return ""

    # 可选：需子类实现
    # 模式
    # return: bool
    def _getIsReleaseMode(self):
        return False

    # 可选：需子类实现
    # 是否允许 Xcode 自动签名生成 provisioning
    def _isEnableAutoSigningAndGenProfile(self):
        return False

    # 可选：需子类实现
    # 是否强制开启 更新 *.md 文本内容 的功能；若开启则每次打包必须填写更新内容
    # return: bool
    def _isForceEnableUpdateMd(self):
        return False

    # 可选：需子类实现
    # 获取更新文件 *.md 的 basename；若为空则默认为 update
    # return: string
    def _getUpdateMdBasename(self):
        return ""

    # 可选：需子类实现
    # 检查 *.md 的文件内容格式是否正确
    # return: bool
    def _isUpdateMdContentValid(self):
        return True


    # 可选：需子类实现
    # 设置指定的 profile；为空则使用
    # return: [(BundleID: string, ProfileBaseName: string), ...]   #
    def _getProvisioningProfiles(self):
        return []

    # 可选：需子类实现
    # 设置指定的 证书；为空则使用
    # return: string
    def _getSigningCertificate(self):
        return ""


    # 当 update.md 文件为空时的回调
    def _onErrorUpdateMdEmpty(self):
        pass


    # 可选：需子类实现
    # 获取用于上传到 appstore 的 API KEY
    # return: string
    def _getUploadAppstoreApiKey(self):
        return ""

    # 可选：需子类实现
    # 获取用于上传到 appstore 的 API ISSUER
    # return: string
    def _getUploadAppstoreApiIssuer(self):
        return ""

    # 可选：需子类实现
    # 获取用于上传到 appstore 的 AuthKey_ApiKey.p8 文件的存放目录；未设置则使用 ~/.private_keys/
    # return: string
    def _getUploadAppstoreApiP8Dir(self):
        return ""














#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/22
# @time: 10:15
# @doc: 版本管理：由 Major.Minor.Patch 组成
# Copyright © 2019 natloc. All rights reserved.
#

import nat.string



# 判断是否合法的版本号
# return: bool
def isValid(vsnStr):
    vsnArr = vsnStr.split(".")

    if 3 != len(vsnArr):
        return False

    major = nat.string.trim(vsnArr[0])
    minor = nat.string.trim(vsnArr[1])
    patch = nat.string.trim(vsnArr[2])

    if not nat.string.isIntStr(major) or int(major) < 0:
        return False

    elif not nat.string.isIntStr(minor) or int(minor) < 0:
        return False

    elif not nat.string.isIntStr(patch) or int(patch) < 0:
        return False

    else:
        return True


# 转为版本号码
# return: string   # 如："010101"
def toCodeStr(vsnStr):
    if not isValid(vsnStr):
        return ""

    vsnArr = vsnStr.split(".")
    major = int(nat.string.trim(vsnArr[0]))
    minor = int(nat.string.trim(vsnArr[1]))
    patch = int(nat.string.trim(vsnArr[2]))

    return "%02d%02d%02d" %(major, minor, patch)


#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/11
# @time: 21:40
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#

import sys
import nat.cmd


# 设置默认为 utf8 编码
def setDefaultUTF8():
    __setDefaultEncoding('utf-8')


# 设置默认编码
def __setDefaultEncoding(encoding):
    if nat.cmd.isPythonVsn2():
        reload(sys)
        sys.setdefaultencoding(encoding)





#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/11
# @time: 15:38
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#

import os
import sys
import shutil

import nat.cmd
import nat.string

# MARK:- 路径

# 获取当前路径：即当前 shell 所在的路径
def cwd():
    return os.getcwd()

# 切换当前工作区目录
# return bool
def changeCwd(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        os.chdir(absPath)
        return True
    else:
        return False

# 获取用户的 Home 目录地址
# return: string
def getUserHomePath():
    return nat.string.trim(nat.cmd.executeRead("echo ~").read())


# MARK:- 档案类型

# 判断是否文件
def isFile(file):
    return os.path.isfile(getAbsPath(file))

# 判断是否合法的文件路径；不对该文件是否存在做判断
def isValidFilePath(file):
    absPath = getAbsPath(file)
    if "" == absPath:
        return False

    dirPath = os.path.dirname(absPath)
    filename = os.path.basename(absPath)
    (basename, suffixWithDot) = os.path.splitext(filename)

    # .xxx 文件
    if "" == suffixWithDot and basename == filename and len(filename) > 0 and "." == filename[0]:
        return isDir(dirPath)

    else:
       return isDir(dirPath) and "" != basename and len(suffixWithDot) > 1 and "." == suffixWithDot[0]

# 判断是否目录
def isDir(path):
    return os.path.isdir(getAbsPath(path))

# 判断是否存在；可能是 文档 或 目录
def isExist(path):
    return os.path.exists(getAbsPath(path))


# MARK:- 列举目录下档案

# 列举指定目录下的 filename 列表
# return [string]
def listDir(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        return os.listdir(absPath)
    else:
        return []


# MARK:- 增删目录

# 创建目录
def mkDir(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        return True
    elif isExist(absPath):
        return False
    else:
        os.mkdir(absPath)
        return True

# 递归创建目录
def mkDirRecursive(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        return True
    elif isExist(absPath):
        return False
    else:
        os.makedirs(absPath)
        return True


# 删除指定的目录、及其内部所有档案
# return: bool
def rmDirRecursive(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        shutil.rmtree(absPath)
        return True
    else:
        return False

# 删除文件
def rmFile(path):
    absPath = getAbsPath(path)
    if isFile(absPath):
        os.remove(absPath)
        return True
    else:
        return False

# 拷贝目录
# return: bool
def cpDir(fromDir, toDir):
    fromDir = nat.string.trim(fromDir)
    toDir = nat.string.trim(toDir)

    return isDir(fromDir) and mkDirRecursive(toDir) and nat.cmd.execute("cp -a %s %s" %(fromDir, toDir))


# 修改文件的 basename 部分
# return: bool
def renameFile(path, newBasename):
    absPath = getAbsPath(path)
    newBasename = nat.string.trim(newBasename)

    if "" == newBasename or not isExist(absPath):
        return False

    else:
        dirPath = getDirPath(absPath)
        suffixWithDot = getFileSuffixWithDot(absPath)
        newPath = join(dirPath, "%s%s" %(newBasename, suffixWithDot))
        os.rename(path, newPath)
        return True




# MARK:- 文件名

# 获取文件名
def getFilename(path):
    absPath = getAbsPath(path)
    if isExist(absPath):
        return os.path.basename(absPath)
    else:
        return ""

# 获取 basename
def getBasename(path):
    absPath = getAbsPath(path)
    if isFile(absPath):
        return os.path.splitext(absPath)[0]
    elif isDir(absPath):
        return os.path.basename(absPath)
    else:
        return ""

# 获取 suffix
def getFileSuffixWithDot(path):
    absPath = getAbsPath(path)
    if isFile(absPath):
        return os.path.splitext(absPath)[1]
    else:
        return ""

# 获取 suffix
def getFileSuffix(path):
    suffixWithDot = getFileSuffixWithDot(path)
    if "" == suffixWithDot:
        return ""
    elif "." == suffixWithDot[0] and len(suffixWithDot) > 1:
        return suffixWithDot[1:]
    else:
        return ""



# MARK:- 拼接

# 拼接路径
def join(path1, path2):
    return os.path.join(path1, path2)

# 获取绝对路径
# 注意：
#   拼接规则：
#       1. 若参数 path 为 "." 时：返回当前绝对路径
#       2. 若参数 path 为 ".." 时：返回当前路径的上一级路径
#       3. 若参数 path 以 "/" 开头时：返回参数
#       4. 否则：返回 "当前路径/Path" 的组合路径
def getAbsPath(path):
    argPath = nat.string.trim(path)
    if nat.string.isNotEmpty(argPath):
        return os.path.abspath(argPath)
    else:
        return ""




# 获取路径的目录
def getDirPath(path):
    absPath = getAbsPath(path)
    if isExist(absPath):
        return os.path.dirname(absPath)
    else:
        return ""



def isFilePlist(path):
    return __isTargetFile(path, "plist")

def isFilePng(path):
    return __isTargetFile(path, "png")

def isFileJpg(path):
    return __isTargetFile(path, "jpg") or __isTargetFile(path, "jpeg")

def __isTargetFile(path, suffix):
    return isFile(path) and (".%s" %(suffix)) == getFileSuffixWithDot(path).lower()



# MARK:- sys 脚本路径

# 获取脚本的包路径列表
# return [string]
def getScriptPathList():
    return sys.path

# 获取执行脚本所在的路径：即通过 python 命令直接执行的脚本所在的路径
def getExecScriptPath():
    list = getScriptPathList()
    if 0 == len(list):
        return ""
    else:
        return list[0]

# 插入脚本路径
# return bool
def insertScriptPath(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        if not hasContainScriptPath(absPath):
            sys.path.insert(0, path)

        return True
    else:
        return False

# 追加脚本路径
# return bool
def appendScriptPath(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        if not hasContainScriptPath(absPath):
            sys.path.append(path)

        return True
    else:
        return False

# 判断是否已包含了指定路径
def hasContainScriptPath(path):
    absPath = getAbsPath(path)
    if isDir(absPath):
        for p in getScriptPathList():
            if p == absPath:
                return True

    return False






#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019-10-21
# @time: 23:44
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#


import nat.string



__globalMap = {}





# 判断是否有键值对
# return: bool
def hasKey(keyStr):
    keyStr = nat.string.trim(keyStr)
    return keyStr in __globalMap



# 根据键获取值
# return: Any
def get(keyStr):
    keyStr = nat.string.trim(keyStr)
    return __globalMap.get(keyStr, None)

# 获取字符串值
# return: string
def getStr(keyStr, defValue = ""):
    value = get(keyStr)
    if nat.string.isStr(value):
        return value
    elif None == defValue:
        return ""
    else:
        return defValue

# 获取整型值
# return: int
def getInt(keyStr, defValue = 0):
    value = get(keyStr)
    if isinstance(value, int):
        return value
    elif None == defValue:
        return 0
    else:
        return defValue


# 获取布尔值
# return: bool
def getBool(keyStr, defValue = False):
    value = get(keyStr)
    if isinstance(value, bool):
        return value
    elif None == defValue:
        return False
    else:
        return defValue



# 设置键值对
# param: value :: Any   # 当 value 为 None 时移除键值对
# return: bool
def set(keyStr, value):
    keyStr = nat.string.trim(keyStr)
    if "" == keyStr:
        return False

    elif None == value:
        del __globalMap[keyStr]
        return True

    else:
        __globalMap[keyStr] = value
        return True





#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/11
# @time: 11:57
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#

import nat.cmd
import nat.string



# 获取当前差异内容
# return string
def status_retStr():
    ret = nat.cmd.executeRead("git status")

    if nat.cmd.isLastCmdSuccess():
        return ret.read()
    else:
        return ""

# 是否已提交完所有变更
# return: bool
def status_isClean():
    return status_retStr().find("nothing to commit, working tree clean") >= 0

# 是否有内容变更需要提交
# return: bool
def status_isCommitable():
    return status_retStr().find("Changes to be committed:") >= 0

# 是否有内容需要 git add 添加
# return: bool
def status_isAddable():
    return status_retStr().find("Changes not staged for commit:") >= 0


# 下载代码
# return: bool
def clone(url):
    url = nat.string.trim(url)
    if "" != url:
        return nat.cmd.execute("git clone %s" %(url))
    else:
        return False

# 刷新
# return: bool
def fetch():
    return nat.cmd.execute("git fetch")

# 更新代码
# return: bool
def pull(branchName = "master", repoName = "origin", enableEdit = True):
    branchName = nat.string.trim(branchName)
    repoName = nat.string.trim(repoName)

    if "" == branchName or "" == repoName:
        return False
    else:
        editMode = ""
        if not enableEdit:
            editMode = "--no-edit"
        return nat.cmd.execute("git pull %s %s %s" %(repoName, branchName, editMode))


# 添加所有修改
# return: bool
def add():
    return nat.cmd.execute("git add .")



# 提交
# return: bool
def commit(messageStr):
    nat.cmd.execute(u"git commit -m \"%s\"" %(messageStr))

# 添加并提交
# return: bool
def addAndCommit(messageStr):
    return add() and commit(messageStr)


# 推送代码
# return: bool
def push(branchName = "master", repoName = "origin", withTags = False):
    branchName = nat.string.trim(branchName)
    repoName = nat.string.trim(repoName)

    if "" == branchName or "" == repoName:
        return False
    else:
        if withTags:
            withTagsStr = "--tags"
        else:
            withTagsStr = ""

        return nat.cmd.execute("git push %s %s %s" %(repoName, branchName, withTagsStr))





# 获取所有分支列表
# return: [string]
def branch_list():
    ret = nat.cmd.executeRead("git branch")

    branchList = []
    if nat.cmd.isLastCmdSuccess():
        for line in ret.readlines():
            branch = line.lstrip("*").strip()
            if "" != branch:
                branchList.append(branch)


    return branchList

# 获取当前分支名
# return: string
def branch_current():
    ret = nat.cmd.executeRead("git branch")

    if nat.cmd.isLastCmdSuccess():
        for line in ret.readlines():
            if 0 == line.find("* "):
                return line.lstrip("*").strip()

    return ""

# 判断当前是否主分支
# return: bool
def branch_isCurMaster():
    return "master" == branch_current()

# 判断是否有指定的分支
# return: bool
def branch_hasBranch(branchNameStr):
    for branch in branch_list():
        if branch == branchNameStr:
            return True

    return False

# 切换分支；如果目标分支不存在则返回 false
# return bool
def branch_switch(branchNameStr):
    if branch_hasBranch(branchNameStr):

        if branch_current() == branchNameStr:
            return True
        else:
            nat.cmd.execute(u"git checkout %s" %(branchNameStr))
            return branch_current() == branchNameStr

    else:
        return False

# 切换分支；如果目标分支不存在则自动创建
# # return bool
def branch_switchSafety(branchNameStr):
    if branch_switch(branchNameStr):
        return True

    branchNameStr = nat.string.trim(branchNameStr)
    if "" != branchNameStr and nat.cmd.execute(u"git checkout -b %s" %(branchNameStr)):
        return True

    else:
        return False



# 添加 tag 名
# return: bool
def tag_add(tagNameStr):
    tagNameStr = nat.string.trim(tagNameStr)
    if "" == tagNameStr:
        return False
    else:
        return nat.cmd.execute("git tag %s" %(tagNameStr))

# 移除 tag 名
# return: bool
def tag_remove(tagNameStr):
    tagNameStr = nat.string.trim(tagNameStr)
    if "" == tagNameStr:
        return False
    else:
        return nat.cmd.execute("git tag -d %s" %(tagNameStr))











#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/12
# @time: 11:20
# @doc: 企业微信群机器人
# Copyright © 2019 natloc. All rights reserved.
#
# 文档：https://work.weixin.qq.com/api/doc?notreplace=true&version=2.8.10.6069&platform=mac#90000/90136/91770
#


import nat.string
import nat.json
import nat.cmd
import nat.path
import nat.log
import nat.file
import nat.phone


# 基础消息
class __Message(object):

    __HTTP_HEADER_CONTENT_TYPE = "Content-Type: application/json"
    _ERROR_MSG_PREFIX = u"企业微信群机器人 * "

    # 机器人的地址
    __webHookUrl = ""


    def __init__(self, webHookUrl):
        self.__webHookUrl = nat.string.trim(webHookUrl)

        if "" == self.__webHookUrl:
            nat.log.error(u"%s实例化失败：机器人的 webhook 地址为空字符串" %(self._ERROR_MSG_PREFIX))


    # 发送消息
    # param: msgType :: string
    # param: jsonData :: json
    # return: bool
    def _send(self, msgType, jsonDict):
        argMsgType = nat.string.trim(msgType)

        if "" == self.__webHookUrl:
            nat.log.error(u"%s发送消息失败：机器人的 webhook 地址为空字符串" %(self._ERROR_MSG_PREFIX))
            return False

        elif "" == argMsgType:
            nat.log.error(u"%s发送消息失败：消息类型错误" %(self._ERROR_MSG_PREFIX))
            return False

        elif not isinstance(jsonDict, dict):
            nat.log.error(u"%s发送消息失败：消息内容类型错误" %(self._ERROR_MSG_PREFIX))
            return False

        else:
            msgJson = {}
            msgJson["msgtype"] = msgType
            msgJson[msgType] = jsonDict

            jsonStr = nat.json.json2str(msgJson)
            cmdStr = "curl %s -H '%s' -d '%s'" %(self.__webHookUrl, self.__HTTP_HEADER_CONTENT_TYPE, jsonStr)
            return nat.cmd.execute(cmdStr)



# text 消息
class TextMessage(__Message):

    __KEY_CONTENT = "content"
    __KEY_MENTIONED_LIST = "mentioned_list"
    __KEY_MENTIONED_MOBILE_LIST = "mentioned_mobile_list"

    # 消息数据
    __msgJson = {}


    # 设置消息内容
    def setContent(self, contentStr):
        self.__msgJson[self.__KEY_CONTENT] = nat.string.trim(contentStr)
        return self


    # 设置提醒所有人
    def setMentionedAll(self):
        self.__msgJson[self.__KEY_MENTIONED_LIST] = ["@all"]
        self.__msgJson[self.__KEY_MENTIONED_MOBILE_LIST] = []
        return self


    # 追加提醒人的 ID
    # param: userId :: string   # 如："lilei"
    # return: bool
    def appendMentionedUser(self, userId):
        argUserId = nat.string.trim(userId)
        if "" == argUserId:
            nat.log.error(u"%s添加提醒人的 ID 失败：用户 ID 为空字符串" %(self._ERROR_MSG_PREFIX))
            return self

        else:
            mentionedList = self.__msgJson.get(self.__KEY_MENTIONED_LIST, [])

            if 1 == len(mentionedList) and "@all" == mentionedList[0]:
                mentionedList = []

            for uid in mentionedList:
                if uid == argUserId:
                    return True

            mentionedList.append(argUserId)
            self.__msgJson[self.__KEY_MENTIONED_LIST] = mentionedList
            return self


    # 追加提醒人的 手机号
    # return: bool
    def appendMentionedPhone(self, phoneNumStr):
        argPhoneNumStr = nat.string.trim(phoneNumStr)
        if not nat.phone.isValid(argPhoneNumStr):
            nat.log.error(u"%s添加提醒人的 手机号 失败：手机号不合法 %s" %(self._ERROR_MSG_PREFIX, argPhoneNumStr))
            return self

        else:
            mentionedList = self.__msgJson.get(self.__KEY_MENTIONED_LIST, [])
            if 1 == len(mentionedList) and "@all" == mentionedList[0]:
                self.__msgJson[self.__KEY_MENTIONED_LIST] = []


            mentionedMobileList = self.__msgJson.get(self.__KEY_MENTIONED_MOBILE_LIST, [])
            for phone in mentionedMobileList:
                if phone == argPhoneNumStr:
                    return True

            mentionedMobileList.append(argPhoneNumStr)

            self.__msgJson[self.__KEY_MENTIONED_MOBILE_LIST] = mentionedMobileList

            return self


    # 发送消息
    # return: bool
    def send(self):
        contentStr = self.__msgJson.get(self.__KEY_CONTENT, "").strip()
        mentionedUserIdList = self.__msgJson.get(self.__KEY_MENTIONED_LIST, [])
        mentionedPhoneList = self.__msgJson.get(self.__KEY_MENTIONED_MOBILE_LIST, [])
        if "" == contentStr and [] == mentionedPhoneList and [] == mentionedUserIdList:
            nat.log.warn(u"%s发送消息失败：取消发送无意义的内容" %(self._ERROR_MSG_PREFIX))
            return

        else:
            return self._send("text", self.__msgJson)



# markdown 消息
class MarkdownMessage(__Message):

    __KEY_CONTENT = "content"
    __DEFAULT_HEAD_SIZE = 3

    # 消息数据
    __msgJson = {}

    # 内容文本
    __content = ""



    # 设置链接
    def mkLink(self, contentStr, urlStr):
        argContentStr = nat.string.trim(contentStr)
        argUrlStr = nat.string.trim(urlStr)

        if "" == argContentStr:
            return ""

        elif "" == argUrlStr:
            return contentStr

        else:
            return u"[%s](%s)" %(argContentStr, argUrlStr)




    # 添加绿色文本
    # return: string
    def mkColorGreen(self, contentStr):
        return self.__mkTextColor("info", contentStr)

    # 添加橙色文本
    # return: string
    def mkColorOrange(self, contentStr):
        return self.__mkTextColor("warning", contentStr)

    # 添加灰色文本
    # return: string
    def mkColorGray(self, contentStr):
        return self.__mkTextColor("comment", contentStr)

    # return: string
    def __mkTextColor(self, typeStr, contentStr):
        if "" == contentStr:
            return ""
        else:
            return u"<font color=\"%s\">%s</font>" %(typeStr, contentStr)



    # 追加字符串
    def append(self, contentStr, isBold = False, isQuote = False, fragmentCount = 0, shouldAppendNewLine = False):
        if nat.string.isNotEmpty(contentStr):

            # 粗体
            if isBold:
                contentStr = "**%s**" %(contentStr)

            # 引用
            if isQuote:
                contentStr = "> %s" %(contentStr)

            # 标题
            fragmentCount = min(6, max(0, fragmentCount))
            fragPrefix = ""
            for _ in range(0, fragmentCount):
                fragPrefix += "#"
            if "" != fragPrefix:
                contentStr = "%s %s" %(fragPrefix, contentStr)

            # 换行
            if shouldAppendNewLine:
                contentStr = "%s\n" %(contentStr)

            self.__content += contentStr

        return self



    # 发送消息
    # return: bool
    def send(self):
        contentStr = nat.string.trim(self.__content)
        if "" == contentStr:
            nat.log.warn(u"%s发送 md 消息失败：取消发送无意义的内容" %(self._ERROR_MSG_PREFIX))
            return

        else:
            self.__msgJson[self.__KEY_CONTENT] = contentStr
            return self._send("markdown", self.__msgJson)



# image 消息
class ImageMessage(__Message):

    __KEY_BASE_64 = "base64"
    __KEY_MD_5 = "md5"

    # 消息数据
    __msgJson = {}

    # 要发送的图片地址
    __imgPath = ""


    # 设置图片；仅支持 png | jpg 格式，且 <= 2M
    # return: bool
    def setImg(self, path):
        if not nat.path.isFile(path):
            nat.log.error(u"%s设置图片失败：文件不存在：%s" %(self._ERROR_MSG_PREFIX, path))
            return False

        suffixWithDot = nat.path.getFileSuffixWithDot(path)
        if ".png" != suffixWithDot and ".jpg" != suffixWithDot and ".jpeg" != suffixWithDot:
            nat.log.error(u"%s设置图片失败：不支持的图片格式：%s" %(self._ERROR_MSG_PREFIX, suffixWithDot))
            return False

        self.__imgPath = nat.path.getAbsPath(path)
        return True


    # 发送消息
    # return: bool
    def send(self):
        if not nat.path.isFile(self.__imgPath):
            nat.log.warn(u"%s发送消息失败：未设置要发送的图片" %(self._ERROR_MSG_PREFIX))
            return False


        base64Str = nat.file.getBase64(self.__imgPath)
        md5Str = nat.file.getMd5(self.__imgPath)
        if "" == base64Str or "" == md5Str:
            nat.log.warn(u"%s发送消息失败：图片解析失败" %(self._ERROR_MSG_PREFIX))
            return

        else:
            self.__msgJson[self.__KEY_BASE_64] = base64Str
            self.__msgJson[self.__KEY_MD_5] = md5Str
            return self._send("image", self.__msgJson)



# news 消息
class NewsMessage(__Message):

    __KEY_ARTICLES = "articles"
    __KEY_TITLE = "title"
    __KEY_DESC = "description"
    __KEY_URL = "url"
    __KEY_PIC_URL = "picurl"


    # 消息数据
    __msgJson = {}

    __MAX_NEWS_COUNT = 8


    # 添加一条新闻
    def appendNews(self, title, desc, url, picUrl):
        newsList = self.__msgJson.get(self.__KEY_ARTICLES, [])

        if len(newsList) >= self.__MAX_NEWS_COUNT:
            nat.log.error(u"%s添加新闻消息失败：已达最大新闻数量" %(self._ERROR_MSG_PREFIX))
            return False

        argTitle = nat.string.trim(title)
        argDesc = nat.string.trim(desc)
        argUrl = nat.string.trim(url)
        argPicUrl = nat.string.trim(picUrl)

        if "" == argTitle:
            nat.log.error(u"%s添加新闻消息失败：标题为空，链接：%s" %(self._ERROR_MSG_PREFIX, argUrl))
            return False
        elif "" == argUrl:
            nat.log.error(u"%s添加新闻消息失败：链接为空，标题：%s" %(self._ERROR_MSG_PREFIX, argTitle))
            return False
        else:
            news = {}
            news[self.__KEY_TITLE] = argTitle
            news[self.__KEY_DESC] = argDesc
            news[self.__KEY_URL] = argUrl
            news[self.__KEY_PIC_URL] = argPicUrl

            newsList.append(news)
            self.__msgJson[self.__KEY_ARTICLES] = newsList
            return True


    # 发送消息
    # return: bool
    def send(self):
        if 0 == len(self.__msgJson.get(self.__KEY_ARTICLES, [])):
            nat.log.warn(u"%s发送 md 消息失败：取消发送无意义的内容" %(self._ERROR_MSG_PREFIX))
            return

        else:
            return self._send("news", self.__msgJson)















#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc
# @date: 2019/10/11
# @time: 11:59
# @doc:
# Copyright © 2019 natloc. All rights reserved.
#

import sys

__colorDefault = 0
__colorRed = 91
__colorGreen = 92
__colorBlue = 96
__colorYellow = 93
__colorPurple = 95



def debug(contentStr):
    __printWithColor(__colorDefault, "debug", contentStr)

def warn(contentStr):
    __printWithColor(__colorGreen, "warn", contentStr)

def error(contentStr):
    __printWithColor(__colorRed, "error", contentStr)

def exit(contentStr):
    __printWithColor(__colorRed, "exit", contentStr)
    sys.exit(1)



# MARK:- 内部方法

def __printWithColor(colorInt, tag, contentStr):
    print(u"\033[%im[%-5s]=== %s\033[%im" %(colorInt, tag, contentStr, __colorDefault))





#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2020/1/2
# @time: 17:14
# @doc:
# Copyright © 2020 natloc_developer. All rights reserved.
#

from bs4 import BeautifulSoup

import nat.cmd
import nat.log
import nat.datetime


__ACCOUNT_USER = "luxiaolong"
__ACCOUNT_PASSWD = "654321qwerQ"


# 根据 issue code 获取标题
def reqJiraTitle(code):
    jiraUrl = u"http://jira.xiaobangtouzi.com/browse/FQ-%i" %(code)

    cmdStr = u"curl -u %s:%s %s" %(__ACCOUNT_USER, __ACCOUNT_PASSWD, jiraUrl)
    html = nat.cmd.executeRead(cmdStr).read()
    htmlLabelArr = BeautifulSoup(html, "html.parser").select("#summary-val")

    if None != htmlLabelArr and None != htmlLabelArr[0]:
        return htmlLabelArr[0].get_text()
    else:
        return u"FQ-%i" %(code)


# 输出耗时
def printArchiveDuration(startTi):
    __costSeconds = int(nat.datetime.getTi() - startTi)
    __costMinutes = __costSeconds / 60
    __costSeconds = __costSeconds % 60
    nat.log.warn(u"完成打包任务，共耗时：%i 分 %i 秒" % (__costMinutes, __costSeconds))


# 同步数据到 QA 集成平台
def syncQualityQA(appName, version, code, branchName, platform, commitId, mode, submitter, downloadUrl):
    __QUALITY_QA_URL = "https://quality-qa.xiaobangtouzi.com/treasure/api/v1/create"
    __QUALITY_QA_HEADER = "Content-Type:application/json"
    __QUALITY_QA_DATA = """{"name": "%s","version_name": "%s", "version": "%s", "branch": "%s", "platform": "%s", "commit_id": "%s", "type": "%s", "submitter": "%s", "created": "%s", "url": "%s"}"""

    quality_qa_data = __QUALITY_QA_DATA %(appName, version, code, branchName, platform, commitId, mode, submitter, nat.datetime.now(), downloadUrl)
    quality_qa_requrest = "curl '%s' -H '%s' -d '%s'" % (__QUALITY_QA_URL, __QUALITY_QA_HEADER, quality_qa_data)

    nat.cmd.execute(quality_qa_requrest)




#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2020/1/5
# @time: 10:21
# @doc: 处理 ics 日历文件
# Copyright © 2020 natloc_developer. All rights reserved.
#

import nat.cmd
import nat.net
import nat.string
import nat.log
import nat.datetime


import icalendar


# MARK:- 类
class ICS:
    # MARK:- 私有属性
    __CALENDAR_URL = "https://p12-caldav.icloud.com/published/2"

    __calendarID = ""
    __ical = ""
    __calendar = None


    # MARK:- 初始化

    def __init__(self, calendarID):
        self.__calendarID = nat.string.trim(calendarID)
        if "" == self.__calendarID:
            nat.log.error(u"日历ID为空字符串")


    # MARK:- 成员函数

    # 请求网络日历数据
    def reqIcal(self):
        urlStr = "%s/%s" % (self.__CALENDAR_URL, self.__calendarID)

        try:
            self.__ical = nat.net.reqUrl(urlStr)
            if "" == self.__ical:
                nat.log.error(u"无法请求日历数据")
            else:
                self.__calendar = icalendar.Calendar.from_ical(self.__ical)
        except Exception as err:
            nat.log.error(f"请求日历数据失败：{err}")

        return self

    # 获取事件列表
    # return: [Event]
    def getEventList(self):
        eventList = []

        if None != self.__calendar:
            for component in self.__calendar.subcomponents:
                if 'VEVENT' == component.name:
                    eventList.append(component)

        return eventList

    # 判断是否事件日；只考虑起始和结束的日期，不考虑时间
    # return: bool
    def isEventDay(self, datetimeObj = nat.datetime.now()):
        dateInt = nat.datetime.getDateInt(datetimeObj)
        if dateInt > 0:
            for event in self.getEventList():
                startDateInt = nat.datetime.getDateInt(icalendar.vDDDTypes.from_ical(event['dtstart']))
                endDateInt = nat.datetime.getDateInt(icalendar.vDDDTypes.from_ical(event['dtend']))

                if startDateInt <= dateInt and dateInt <= endDateInt:
                    return True

        return False


# MARK:- 小帮规划
class ICS_XiaoBangGuiHua(ICS):
    # MARK:- 私有属性
    __XiaoBangGuiHua_CALENDAR_ID = "MTk1NTE5NTI3NzE5NTUxOZf-83pNOHq6gqW6ycF5AeDNvGxRdUYC-Z5oE7CRAisq"

    def __init__(self):
        super().__init__(self.__XiaoBangGuiHua_CALENDAR_ID)


#!/usr/bin/python3
# -*- coding: utf8 -*-
#
# @author: natloc_developer
# @date: 2019/12/31
# @time: 16:52
# @doc:
# Copyright © 2019 natloc_developer. All rights reserved.
#

import time
import datetime


# 获取时间戳
# return double
def getTi():
    return time.time()


# 获取当前时刻的对象
# 可直接获取成员属性；如：now = nat.datetime.now(); now.year
def now():
    return datetime.datetime.now()


# 获取日期数字
# return: int   # 如：20190909
def getDateInt(datetimeObj):
    if datetime.datetime != type(datetimeObj):
        return 0
    else:
        return (datetimeObj.year * 10000) + (datetimeObj.month * 100) + datetimeObj.day
